Learn R Programming

cgAUC (version 1.2.1)

c_cntin: c_cntin

Description

Continue function, when variable was continue.

Usage

c_cntin(y, z, l, h)

Arguments

y
The potential variables. It is a matrix with column of values of a variables. It should be standardized in this application.
z
The gold standard variable. It should be standardized.
l
Linear combination. A vector.
h
The value of h falls into (n^(-1/2), n^(-1/5)).

Value

  • theta.sh.h.pThe estimate of the theta of Chang(2012).
  • varThe variance of estimate of the theta of Chang(2012).

References

Chang, YCI. Maximizing an ROC type measure via linear combination of markers when the gold reference is continuous. Statistics in Medicine 2012. Obuchowski NA. An ROC-type measure of diagnostic accuracy when the gold standard is continuous-scale. Statistics in Medicine 2006; 25:481--493. Obuchowski N. Estimating and comparing diagnostic tests accuracy when the gold standard is not binary. Statistics in Medicine 2005; 20:3261--3278. Friedman JH, Popescu BE. Gradient directed regularization for linear regression and classification. Technical Report, Department of Statistics, Stanford University, 2004.

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function(y, z, l, h) {
    .Call('cgAUC_c_cntin', PACKAGE = 'cgAUC', y, z, l, h)
}

Run the code above in your browser using DataLab