Learn R Programming

cgAUC (version 1.2.1)

c_dscrt: c_dscrt

Description

discrete function, when variable is discrete.

Usage

c_dscrt(y, z, l)

Arguments

y
The potential variables. It is a matrix with column of values of a variables. It should be standardized in this application.
z
The gold standard variable. It should be standardized.
l
Linear combination. A vector.

Value

  • theta.h.pThe estimate of theta when variable is discrete.
  • varThe variance of estimate of theta.

Details

Discrete function, when variable is discrete.

References

Chang, YCI. Maximizing an ROC type measure via linear combination of markers when the gold reference is continuous. Statistics in Medicine 2012. Obuchowski NA. An ROC-type measure of diagnostic accuracy when the gold standard is continuous-scale. Statistics in Medicine 2006; 25:481--493. Obuchowski N. Estimating and comparing diagnostic tests accuracy when the gold standard is not binary. Statistics in Medicine 2005; 20:3261--3278. Friedman JH, Popescu BE. Gradient directed regularization for linear regression and classification. Technical Report, Department of Statistics, Stanford University, 2004.

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function(y, z, l) {
    .Call('cgAUC_c_dscrt', PACKAGE = 'cgAUC', y, z, l)
}

Run the code above in your browser using DataLab