Learn R Programming

cgAUC (version 1.2.1)

c_s_h: c_s_h

Description

Smooth function.

Usage

c_s_h(t, h)

Arguments

t
A value, the difference between any two subjects.
h
The value of h falls into (n^(-1/2), n^(-1/5)).

Value

  • s_hThe value of smooth function.

Details

Smooth function.

References

Chang, YCI. Maximizing an ROC type measure via linear combination of markers when the gold reference is continuous. Statistics in Medicine 2012. Obuchowski NA. An ROC-type measure of diagnostic accuracy when the gold standard is continuous-scale. Statistics in Medicine 2006; 25:481--493. Obuchowski N. Estimating and comparing diagnostic tests accuracy when the gold standard is not binary. Statistics in Medicine 2005; 20:3261--3278. Friedman JH, Popescu BE. Gradient directed regularization for linear regression and classification. Technical Report, Department of Statistics, Stanford University, 2004.

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function(t, h) {
    .Call('cgAUC_c_s_h', PACKAGE = 'cgAUC', t, h)
}

Run the code above in your browser using DataLab